/****************************************************************************
 *                                                                          
 * Title:   Marker Counter Measurement
 *
 * Purpose: This example shows how to proceed with marker counter measurement.
 *
 ****************************************************************************/

#include <ansi_c.h>
#include "rssifs.h"

/*** Macros & definitions ***************************************************/

#define CHECKERR( fCal ) \
    { \
        fCalStartTime = clock();\
        error = (fCal);\
        status = error;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (error != VI_SUCCESS)\
            {\
            rssifs_error_message (io, error, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", error, error_message);\
            rssifs_error_query(io, &error, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", error, error_message);\
            }\
    }

#define RESOURCE_NAME   "USB::0xAAD::0x6::100202"   // Resource name

/*** Main *******************************************************************/

int main (int argc, char *argv[])
{
    ViStatus    error               = VI_SUCCESS,
                status              = VI_SUCCESS;
    clock_t     fCalTime            = 0,
                fCalStartTime       = 0;
    ViChar      error_message[256];
    ViSession   io;
    
    /* Define remote connection parameters (as default values) */

    ViBoolean   IDQuery             = VI_TRUE,
                resetDevice         = VI_TRUE;
    ViRsrc      resourceName        = RESOURCE_NAME;

    ViReal64    freq_counter        = 0.0;

    CHECKERR (rssifs_init (resourceName, IDQuery, resetDevice, &io));

    printf (

    "\n --- Marker Counter Measurement -----------------------------------------\n\n"
    "\tRF Generator is connected to the analyzer's input\n"
    "\t- Frequency: 1 GHz\n"
    "\t- Level: -30.0 dBm\n"
    "\t- Modulation: AM, modulation frequency 50 kHz, modulation depth 100 %%\n"
    "\n ------------------------------------------------------------------------\n\n"

    );

    printf ("\n --- Set center 1 GHz and span 1.0 MHz\n\n");
    CHECKERR (rssifs_confSpanCenterFrq (io, 0, 1.0e6, 1.0e9));

    /* Set reference level */
    CHECKERR (rssifs_confRefLevel (io, -20.0));
    /* Update data in the trace cache */
    CHECKERR (rssifs_actSendTrgWopc (io, 10000));

    /* Enable marker */
    CHECKERR (rssifs_confMarkState (io, 1, VI_TRUE));
    
    printf ("\n --- Set marker to 1 GHz\n\n");

    CHECKERR (rssifs_confMarkPosition (io, 1, 1.0e9));
    
    printf ("\n --- Configure and activate marker counter\n\n");

    CHECKERR (rssifs_confMarkFreqCnt (io, 1, 1, VI_TRUE));

    CHECKERR (rssifs_readMarkerCounterValue (io, 1, &freq_counter));

    printf ("\n\tFrequency Counter Result [Hz]: %.1Lf\n\n", freq_counter);

    CHECKERR (rssifs_close (io));

    return 0;
}
