/****************************************************************************
 *                                                                          
 * Title:   Measurement in Frequency Domain
 *
 * Purpose: This example shows how to setup measurement in frequency domain.
 *
 ****************************************************************************/

#include <ansi_c.h>
#include "rssifs.h"

/*** Macros & definitions ***************************************************/

#define CHECKERR( fCal ) \
    { \
        fCalStartTime = clock();\
        error = (fCal);\
        status = error;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (error != VI_SUCCESS)\
            {\
            rssifs_error_message (io, error, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", error, error_message);\
            rssifs_error_query(io, &error, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", error, error_message);\
            }\
    }

#define RESOURCE_NAME   "USB::0xAAD::0x6::100202"   // Resource name

/*** Main *******************************************************************/

int main (int argc, char *argv[])
{
    ViStatus    error               = VI_SUCCESS,
                status              = VI_SUCCESS;
    clock_t     fCalTime            = 0,
                fCalStartTime       = 0;
    ViChar      error_message[256];
    ViSession   io;
    
    ViReal64    startFrequency      = 500.0e6,
                stopFrequency       = 1.0e9;
    
    /* Define remote connection parameters (as default values) */

    ViBoolean   IDQuery             = VI_TRUE,
                resetDevice         = VI_TRUE;
    ViRsrc      resourceName        = RESOURCE_NAME;

    CHECKERR (rssifs_init (resourceName, IDQuery, resetDevice, &io));

    printf (

    "\n --- Measurement in Frequency Domain ------------------------------------\n\n"
    "\tRF Generator is connected to the analyzer's input\n"
    "\t- Frequency: 1 GHz\n"
    "\t- Level: -30.0 dBm\n"
    "\t- Modulation: none\n"
    "\n ------------------------------------------------------------------------\n\n"

    );

    /* Set reference level */
    CHECKERR (rssifs_confRefLevel (io, -20.0));
    /* Set start and stop frequency */
    CHECKERR (rssifs_confStartStopFrq (io, 0, startFrequency, stopFrequency));

    /* Read trace data of completed sweep */
    {
        ViInt32     samplesReturned = 0;
        ViReal64    traceData[250];

        CHECKERR (rssifs_readCompleteSweepData (io, traceData, &samplesReturned));

        if (error == VI_SUCCESS)
            {
            printf ("\tSamples Returned: %ld\n"
                    "\tTrace Data [Vrms]: %.3Le, %.3Le, %.3Le ...\n"
                    "\tStart Frequency [Hz]: %.3Le\n"
                    "\tStop Frequency [Hz]: %.3Le\n"
                    "\tFrequency Step [Hz]: %.3Le\n",
                    samplesReturned,
                    traceData[0], traceData[1], traceData[2],
                    startFrequency,
                    stopFrequency,
                    (stopFrequency - startFrequency) / samplesReturned);
            }
    }

    CHECKERR (rssifs_close (io));

    return 0;
}
